@@ -2197,7 +2197,7 @@ class AnalyticsHubServiceClient(metaclass=AnalyticsHubServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "AnalyticsHubServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
